@@ -329,7 +329,7 @@ public:
     }
 
     // Return the square root of the mean of the squared values
-    real rms() const { return count_ > 0 ? squaredSum_ / count_ : 0; }
+    real rms() const { return count_ > 0 ? std::sqrt(squaredSum_ / count_) : 0; }
 
     /* Returns the smallest resolution such that:
      *   |max value| / resolution does not exceed the maximum that can be stored in T
@@ -850,6 +850,8 @@ static real energyDrift(gmx::ArrayRef<const VerletbufAtomtype> att,
         }
     }
 
+    GMX_RELEASE_ASSERT(std::isfinite(drift_tot), "The drift estimate should be a finite value");
+
     return drift_tot;
 }
 
@@ -1112,6 +1114,8 @@ static real computeEffectiveAtomDensity(gmx::ArrayRef<const gmx::RVec> coordinat
                                         const real                     cutoff)
 {
     GMX_RELEASE_ASSERT(!coordinates.empty(), "Need coordinates to compute a density");
+    GMX_RELEASE_ASSERT(cutoff > 0,
+                       "The cutoff must be > 0 when computing the effective atom density");
 
     gmx::IVec numCells;
     gmx::RVec invCellSize;
